==> zio-aws-chimesdkmessaging_2.13-5.17.122.1-sources.jar: zio/aws/chimesdkmessaging/model/DescribeChannelModeratorResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeChannelModeratorResponse(
    channelModerator: Option[zio.aws.chimesdkmessaging.model.ChannelModerator] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse = {
    import DescribeChannelModeratorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse
      .builder()
      .optionallyWith(channelModerator.map(value => value.buildAwsValue()))(
        _.channelModerator
      )
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse
      .wrap(buildAwsValue())
}
object DescribeChannelModeratorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse =
      zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse(
        channelModerator.map(value => value.asEditable)
      )
    def channelModerator
        : Option[zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly]
    def getChannelModerator: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly
    ] = AwsError.unwrapOptionField("channelModerator", channelModerator)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse
  ) extends zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse.ReadOnly {
    override val channelModerator
        : Option[zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly] =
      scala
        .Option(impl.channelModerator())
        .map(value =>
          zio.aws.chimesdkmessaging.model.ChannelModerator.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse
  ): zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmessaging_2.13-5.20.22.3-sources.jar: zio/aws/chimesdkmessaging/model/DescribeChannelModeratorResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeChannelModeratorResponse(
    channelModerator: Optional[
      zio.aws.chimesdkmessaging.model.ChannelModerator
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse = {
    import DescribeChannelModeratorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse
      .builder()
      .optionallyWith(channelModerator.map(value => value.buildAwsValue()))(
        _.channelModerator
      )
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse
      .wrap(buildAwsValue())
}
object DescribeChannelModeratorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse =
      zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse(
        channelModerator.map(value => value.asEditable)
      )
    def channelModerator
        : Optional[zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly]
    def getChannelModerator: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly
    ] = AwsError.unwrapOptionField("channelModerator", channelModerator)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse
  ) extends zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse.ReadOnly {
    override val channelModerator
        : Optional[zio.aws.chimesdkmessaging.model.ChannelModerator.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.channelModerator())
        .map(value =>
          zio.aws.chimesdkmessaging.model.ChannelModerator.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratorResponse
  ): zio.aws.chimesdkmessaging.model.DescribeChannelModeratorResponse.ReadOnly =
    new Wrapper(impl)
}
